==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/dl.php <==
<?php

// PJC 16/09/2019 Updated Help & Assist links

$page_id = "006";
$ma_acl = '';

include "assist/.access.php";
include "assist/tzone.php"; // include timezone
$script=$_SERVER['SCRIPT_NAME']; 

$disabled = (preg_match('/006a/',$ma_acl)) ? "disabled" : "";
$action = (isset ($_REQUEST['action'] )) ? $_REQUEST['action'] : "0";

$ds = ldap_connect("127.0.0.1",4000);
	if ( ! $ds) {
		echo "LDAP connect failure<br>";
	} else {
		$r = ldap_bind($ds,"INTERNAL","0123456");
		if ( ! $r) {
			echo "LDAP bind failure<br>";
			$ds = false;
	}
}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
<title>Department Overview</title>
<meta http-equiv="Content-type" content="text/html; charset=UTF-8"/>
<style type="text/css">
	@import "assist/css/codes/codes_page.css";
	@import "assist/css/codes/codes_table.css";
	@import "assist/css/codes/custom.css";
</style>
<link href="assist/css/Styles.css" rel="stylesheet" type="text/css">
<link href="assist/css/accordion.css" rel="stylesheet" type="text/css">
<script src="assist/js/codes/jquery-1.7.2.min.js" type="text/javascript"></script>
<script src="assist/js/codes/jquery.dataTables.min.js" type="text/javascript"></script>
<script src="assist/js/wiz/main.js" type="text/javascript"></script>

<link href="assist/css/wiz/jquery.toastmessage-min.css" type="text/css" rel="stylesheet"/>
<script src="assist/js/wiz/jquery.toastmessage-min.js" type="text/javascript"></script>

<script type="text/javascript">
$(document).ready(function(){
	
	oTable = $('#exconfig').dataTable({
		"bJQueryUI": true, "sPaginationType": "full_numbers",
		"aLengthMenu": [[10, 25, 50, 100, 250, 500, 1000], [10, 25, 50, 100, 250, 500, 1000]],
	});
	
	$( 'input[type=checkbox]' ).click( function() {
		checkstate = (this.checked) ? '1' : '0';
		checkdn = $(this).attr("data-dn");
		
		$.post(
			'dlupdate.php?checkbox=' + checkstate + '&dn=' + checkdn,
			function( response ) {
				$('#form-response').html( response );
				showSuccessCB( response );
			}
		);
	});
	
	$(function() {
		$(window).scroll(function() {
			if($(this).scrollTop() != 0) {
				$('#toTop').fadeIn();
			} else {
				$('#toTop').fadeOut();
			}
		});
		$('#toTop').click(function() {
			$('body,html').animate({scrollTop:0},800);
		});
	});
	
});

   function showSuccessCB(str) {
        $().toastmessage('showToast', {
	        stayTime : '3000',
            text     : str,
            position : 'top-right',
            type     : 'success',
            closeText: '',
        });
    }
</script>

<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
<body id="dt_excodes">
<div id="toTop">^ Back to Top</div>

<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo "{$script}?action={$action}" ?>'" src="assist/images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('assist/help/help_deptoverview.php','help','600','500','yes');return false" src="assist/images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist/assist.php'" src="assist/images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="assist/images/home16.gif" alt="home" title="home" border="0">
</div>

<div id="container"><div id="codes">
<h3><img src='assist/images/ok.png' style="vertical-align:middle;">&nbsp;System Licences - View Department Status</h3>


This page allows you to examine and reallocate Department Licences.<br>
Changing tickboxes will immediately update the configuration.<br>
The simplest way to recalculate licence totals is to untick then retick an existing Mailbox licence.<br>
"<b>Departments</b>" have a licence, "Departments" have none.</p>

<?php
	echo "<form method='post' id='frm' action='$script'>";
	echo "<table cellpadding='0' cellspacing='0' border='0' class='display' id='exconfig' width='100%'>";
	echo "<thead><tr><th style='width:155px'>Name</th><th style='width:50px'>Extension Number</th><th style='width:155px'>MessageBox</th></tr></thead>
		  <tfoot><tr><th style='width:155px'>Name</th><th style='width:50px'>Extension Number</th><th style='width:155px'>MessageBox</th></tr></tfoot><tbody>";
	

  $sr = ldap_list($ds,"cn=Departments","objectclass=department",array('dn','cn','telephonenumber','messageboxlicense'));
 	   $info = ldap_get_entries($ds, $sr);
       		for ($m=0; $m<$info['count']; $m++) {
				
				$dname = $info[$m]['dn'];
				$cn = ($info[$m]['cn'][0]);
				$telephonenumber = ($info[$m]['telephonenumber'][0]);
				$messageboxlicense[$m] = ($info[$m]['messageboxlicense'][0]); 
				$checked = (isset($info[$m]['messageboxlicense'][0]) && $info[$m]['messageboxlicense'][0] == '1') ? 'checked' : '';
				
					echo "<tr class='even_gradeX'>";
					echo "<td>$cn</td>";
					echo "<td>$telephonenumber</td>";
					echo "<td><input name='checkbox' type='checkbox' data-dn='$dname' $checked $disabled/></td>";
					echo "</tr>";
 
				
				
			}


?>
<div class="form-response" style="display: none;"></div>
</table>	
</div></div>
</body>
</html>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/dl.php <==
<?php

// PJC 16/09/2019 Updated Help & Assist links
// PJC 07/04/2020 Add Department / User / System Links


$page_id = "006";
$ma_acl = '';

include "assist/.access.php";
include "assist/tzone.php"; // include timezone
$script=$_SERVER['SCRIPT_NAME']; 

$disabled = (preg_match('/006a/',$ma_acl)) ? "disabled" : "";
$action = (isset ($_REQUEST['action'] )) ? $_REQUEST['action'] : "0";

$ds = ldap_connect("127.0.0.1",4000);
	if ( ! $ds) {
		echo "LDAP connect failure<br>";
	} else {
		$r = ldap_bind($ds,"INTERNAL","0123456");
		if ( ! $r) {
			echo "LDAP bind failure<br>";
			$ds = false;
	}
}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
<title>Department Overview</title>
<meta http-equiv="Content-type" content="text/html; charset=UTF-8"/>
<style type="text/css">
	@import "assist/css/codes/codes_page.css";
	@import "assist/css/codes/codes_table.css";
	@import "assist/css/codes/custom.css";
</style>
<link href="assist/css/Styles.css" rel="stylesheet" type="text/css">
<link href="assist/css/accordion.css" rel="stylesheet" type="text/css">
<script src="assist/js/codes/jquery-1.7.2.min.js" type="text/javascript"></script>
<script src="assist/js/codes/jquery.dataTables.min.js" type="text/javascript"></script>
<script src="assist/js/wiz/main.js" type="text/javascript"></script>

<link href="assist/css/wiz/jquery.toastmessage-min.css" type="text/css" rel="stylesheet"/>
<script src="assist/js/wiz/jquery.toastmessage-min.js" type="text/javascript"></script>

<script type="text/javascript">
$(document).ready(function(){
	
	oTable = $('#exconfig').dataTable({
		"bJQueryUI": true, "sPaginationType": "full_numbers",
		"aLengthMenu": [[10, 25, 50, 100, 250, 500, 1000], [10, 25, 50, 100, 250, 500, 1000]],
	});
	
	$( 'input[type=checkbox]' ).click( function() {
		checkstate = (this.checked) ? '1' : '0';
		checkdn = $(this).attr("data-dn");
		
		$.post(
			'dlupdate.php?checkbox=' + checkstate + '&dn=' + checkdn,
			function( response ) {
				$('#form-response').html( response );
				showSuccessCB( response );
			}
		);
	});
	
	$(function() {
		$(window).scroll(function() {
			if($(this).scrollTop() != 0) {
				$('#toTop').fadeIn();
			} else {
				$('#toTop').fadeOut();
			}
		});
		$('#toTop').click(function() {
			$('body,html').animate({scrollTop:0},800);
		});
	});
	
});

   function showSuccessCB(str) {
        $().toastmessage('showToast', {
	        stayTime : '3000',
            text     : str,
            position : 'top-right',
            type     : 'success',
            closeText: '',
        });
    }
</script>

<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
<body id="dt_excodes">
<div id="toTop">^ Back to Top</div>

<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '<?php echo "{$script}?action={$action}" ?>'" src="assist/images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('assist/help/help_deptoverview.php','help','600','500','yes');return false" src="assist/images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'assist/assist.php'" src="assist/images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = 'index.php'" src="assist/images/home16.gif" alt="home" title="home" border="0">
</div>

<div style="position:absolute; top:30px; right:10px" >
<?php link_check("006","<a class='orange' href='dl.php' alt='department' title='department'>Department Licence Status</a>&nbsp;|&nbsp;", $ma_acl); ?>
<?php link_check("028","<a class='orange' href='ul.php' alt='user' title='user'>User Licence Status</a>&nbsp;|&nbsp;", $ma_acl); ?>
<?php link_check("041","<a class='orange' href='licences.php' alt='system' title='system'>System Licence Status</a>", $ma_acl); ?>
</div>


<div id="container"><div id="codes">
<h3><img src='assist/images/ok.png' style="vertical-align:middle;">&nbsp;System Licences - View Department Status</h3>


This page allows you to examine and reallocate Department Licences.<br>
Changing tickboxes will immediately update the configuration.<br>
The simplest way to recalculate licence totals is to untick then retick an existing Mailbox licence.<br>
"<b>Departments</b>" have a licence, "Departments" have none.</p>

<?php
	echo "<form method='post' id='frm' action='$script'>";
	echo "<table cellpadding='0' cellspacing='0' border='0' class='display' id='exconfig' width='100%'>";
	echo "<thead><tr><th style='width:155px'>Name</th><th style='width:50px'>Extension Number</th><th style='width:155px'>MessageBox</th></tr></thead>
		  <tfoot><tr><th style='width:155px'>Name</th><th style='width:50px'>Extension Number</th><th style='width:155px'>MessageBox</th></tr></tfoot><tbody>";
	

  $sr = ldap_list($ds,"cn=Departments","objectclass=department",array('dn','cn','telephonenumber','messageboxlicense'));
 	   $info = ldap_get_entries($ds, $sr);
       		for ($m=0; $m<$info['count']; $m++) {
				
				$dname = $info[$m]['dn'];
				$cn = ($info[$m]['cn'][0]);
				$telephonenumber = ($info[$m]['telephonenumber'][0]);
				$messageboxlicense[$m] = ($info[$m]['messageboxlicense'][0]); 
				$checked = (isset($info[$m]['messageboxlicense'][0]) && $info[$m]['messageboxlicense'][0] == '1') ? 'checked' : '';
				
					echo "<tr class='even_gradeX'>";
					echo "<td>$cn</td>";
					echo "<td>$telephonenumber</td>";
					echo "<td><input name='checkbox' type='checkbox' data-dn='$dname' $checked $disabled/></td>";
					echo "</tr>";
 
				
				
			}


?>
<div class="form-response" style="display: none;"></div>
</table>	
</div></div>
</body>
</html>
